# Multi_agents_utils
Multi Agents Utils Using Langgraph,Autogen and CrewAI,LLAMAIndex, Pydantic-AI,SWARM

## Here's a non-exhaustive list of agent frameworks we know about today:
- Langgraph
- CrewAI
- AutoGen
- LlamaIndex
- SmolAgents
- Pydantic AI
- Phidata
- OpenAI Swarm
- Langchain Agents
- DIY
- AWS Bedrock 
- Azure Azure AI Agent Service, powered by Semantic Kernel,



# 1. Langchain Agents
1. https://python.langchain.com/v0.1/docs/modules/agents/

# 2. Using Langgraph
1. https://langchain-ai.github.io/langgraph/tutorials/introduction/#part-1-build-a-basic-chatbot
2. https://langchain-ai.github.io/langgraph/tutorials/


# 3. AutoGen (Microsoft)
1. https://microsoft.github.io/autogen/0.2/docs/Getting-Started/

# 4. CrewAI
1. https://docs.crewai.com/installation
2. https://github.com/IntelegixLabs/Multi_Agent_Collaboration_for_Financial_Analysis
3. https://storage.googleapis.com/lablab-static-eu/presentations/submissions/cm13b8gp0000z357eaunuygdy/cm13b8gp0000z357eaunuygdy-1726399796546_llg46c0iwl.pdf


# 4. LLAMA INDEX  
1. https://www.llamaindex.ai/blog/introducing-llama-agents-a-powerful-framework-for-building-production-multi-agent-ai-systems
2. https://docs.llamaindex.ai/en/stable/use_cases/agents/

# 5. pydantic-ai
1. https://ai.pydantic.dev/examples/chat-app/#example-code
2. https://ai.pydantic.dev/


# 6. OpenAI SWARM
1. pip install git+https://github.com/openai/swarm.git

# OpenAI Agent SDK
1. Refer docs inside 
2. https://medium.com/@agencyai/building-ai-agents-with-openais-agents-sdk-a-beginner-s-guide-66751e5e7e05

# 7. LLAMA-Index SDK
1. Refer docs inside

# AWS strands Agent SDK
1. https://strandsagents.com/0.1.x/user-guide/quickstart/

# 8. Google ADK (Google Agent Development Kit (ADK), an open-source Python library)
1. google & google-adk : https://www.youtube.com/watch?v=P4VFL9nIaIA
2. https://medium.com/@sokratis.kartakis/from-zero-to-multi-agents-a-beginners-guide-to-google-agent-development-kit-adk-b56e9b5f7861
3. https://github.com/sokart/adk-walkthrough/blob/main/chapter2_main_single_agent.py
4. Build your first Voice Assistant with Agent Development Kit (ADK) https://www.youtube.com/watch?v=f0-t_jIW9yY
5. Google Agent Development Kit for Beginners - YouTube https://www.youtube.com/watch?v=r-JsrEoctCQ
6. Google's Agent Development Kit (ADK): A Guide With Demo Project https://www.datacamp.com/tutorial/agent-development-kit-adk
7. Using Google's Agent Development Kit and Agent2Agent - Wandb https://wandb.ai/gladiator/Google-Agent2Agent/reports/Using-Google-s-Agent-Development-Kit-and-Agent2Agent--VmlldzoxMjIyODEwOA
8. Introducing Agent Development Kit - YouTube https://www.youtube.com/watch?v=zgrOwow_uTQ
9. Build AI Agents & Automate Workflows (Beginner to Pro) - YouTube https://www.youtube.com/watch?v=P4VFL9nIaIA
10. The Complete Guide to Google's Agent Development Kit (ADK) https://www.siddharthbharath.com/the-complete-guide-to-googles-agent-development-kit-adk/
11. What Is Agent Development Kit | Build AI Agent Using Agent SDK https://www.youtube.com/watch?v=e-9iy4GWffM
12. Code https://github.com/bhancockio/
13. 
# 9. MCP SDK 
1. ![img_2.png](img_2.png)
2. ![img_3.png](img_3.png)

# 10. dynamiq
1. https://dynamiq-ai.github.io/dynamiq/

# 11. burr
1. https://github.com/DAGWorks-Inc/burr/tree/main

# 12. Hugging face agents (SmolAgent)
1. https://github.com/ashishpatel26/AIAgentWorkshop/tree/main
2. 
# 13. Semantic Kernal
1. https://learn.microsoft.com/en-us/semantic-kernel/overview/?wt.mc_id=slidescontent_25699_webinar_reactor
2. https://learn.microsoft.com/en-us/training/modules/develop-ai-agent-with-semantic-kernel/

# 14. Sherpa Agents 
1. https://github.com/Aggregate-Intellect/sherpa/blob/main/demo/blog_writer/main.py

# 15. AWS Bedrock agent framework
1. https://aws.amazon.com/blogs/machine-learning/design-multi-agent-orchestration-with-reasoning-using-amazon-bedrock-and-open-source-frameworks/
2. https://github.com/aws-samples/agentic-orchestration/tree/main
3. https://catalog.us-east-1.prod.workshops.aws/workshops/d2131e02-4fff-4090-bff9-0c85ecfcf143/en-US
4. https://github.com/awslabs/amazon-bedrock-agent-samples/tree/main?tab=readme-ov-file
5. AWS Bedrock : https://github.com/aws-samples/amazon-bedrock-workshop 
6. https://catalog.us-east-1.prod.workshops.aws/amazon-bedrock/en-US
7. https://catalog.workshops.aws/agents-for-amazon-bedrock/en-US
8. https://github.com/aws-samples/amazon-bedrock-samples/tree/main/rag/knowledge-bases/use-case-examples
9. https://github.com/aws-samples/financial-analysis-multi-agent-collaboration/tree/main
10. https://github.com/aws-samples/bedrock-multi-agents-collaboration-workshop/blob/main/1-energy-forecast/1_forecasting_agent.ipynb

# 16. PocketFlow (100 Lines )
1. https://github.com/The-Pocket/PocketFlow
2. ![img_5.png](img_5.png)
3. ![img_6.png](img_6.png)


## Installation

1. **Clone the repository:**

```bash
$ git clone https://github.com/anjijava16/Multi_agents_utils.git
$ cd Multi_agents_utils
```

2. **Install dependencies with `uv`:**

To install the required dependencies for this project, use the following command with `uv`:

- First, ensure you have `uv` installed. If not, install it globally:

  ```bash
  pip install uv
  ```

- Then, install the dependencies using uv
  ```bash
  uv install
  ```
- Run the application using uv 

  ```bash
  uv run
  ```

- Build the Python package using uv 
  ```bash
  uv build
  ```

# Reference
1. https://medium.com/vedcraft/building-intelligent-apps-with-agentic-ai-top-frameworks-to-watch-for-in-2025-7d461627adf2
2. https://vedcraft.com/tech-trends/building-intelligent-apps-with-agentic-ai-top-frameworks-to-watch-for-in-2025/



![img.png](img.png)
![img_1.png](img_1.png)
![img_4.png](img_4.png)

# 500 AI Agents Repos
1. https://github.com/ashishpatel26/500-AI-Agents-Projects